'''
Author: BDFD
Date: 2021-10-27 18:42:50
LastEditTime: 2022-05-13 10:52:05
LastEditors: BDFD
Description: In User Settings Edit
FilePath: \5.2-PyPi-WES_Calculation\WES_Calculation\__init__.py
'''

from WES_Calculation.templateproj import add_one
from WES_Calculation.templateproj import add_two
from WES_Calculation.gumbel import gumbel
from WES_Calculation.greenampt import greenampt
from WES_Calculation.wavespectra import wave

